@@ -87,6 +87,8 @@ INVALID_IPSET       =  135
 INVALID_ENTRY       =  136
 INVALID_OPTION      =  137
 INVALID_HELPER      =  138
+INVALID_PRIORITY    =  139
+INVALID_POLICY      =  140
 
 MISSING_TABLE       =  200
 MISSING_CHAIN       =  201
@@ -97,6 +99,7 @@ MISSING_NAME        =  205
 MISSING_SETTING     =  206
 MISSING_FAMILY      =  207
 
+RUNNING_BUT_FAILED  =  251
 NOT_RUNNING         =  252
 NOT_AUTHORIZED      =  253
 UNKNOWN_ERROR       =  254
